@@ -1,3 +1,9 @@
+#![no_std]
+
+use alloc::vec::Vec;
+
+extern crate alloc;
+
 /// Returned by `router![]` to signify if the request was handled
 pub enum RouterResult<T, U> {
     /// Response of the request
@@ -103,7 +109,7 @@ pub fn router<T, U>(request: T, routes: &'static [&ConstRoute<T, U>]) -> RouterR
 where
     T: ::mimeograph_request::Request,
 {
-    let request_method: ::std::borrow::Cow<'_, str> =
+    let request_method: ::alloc::borrow::Cow<'_, str> =
         ::mimeograph_request::Request::method(&request);
 
     // create an array of Segments that can be matched
